==> magics++_2.10.0.dfsg.orig.tar.gz: magics++-2.10.0.dfsg/src/basic/Visdef.h <==
/******************************** LICENSE ********************************

 Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at 

    http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 ******************************** LICENSE ********************************/

/*! \file Visdef.h
    \brief Definition of the Template class Visdef.
    
    Magics Team - ECMWF 2007
    
    Started: Fri 16-Mar-2007
    
    Changes:
    
*/

#ifndef Visdef_H
#define Visdef_H

#include "magics.h"
#include "BasicSceneObject.h"
#include "Data.h"


namespace magics {

class MetaDataVisitor;
class Transformation;

template <class P>
class Visdef : public MetviewIcon  {

public:
	Visdef() {}
	virtual ~Visdef() {}
	
	
	virtual void operator()(Data<P>&, BasicGraphicsObjectContainer&) = 0;
	virtual void visit(LegendVisitor&) {}
    virtual void visit(MetaDataVisitor&) {} 
    virtual void visit(Transformation&, Data<P>&) {}
    virtual void visit(Layer& layer) { MetviewIcon::visit(layer); }
protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
	 virtual void print(ostream& out) const { 
	 	out << "visdef"; 
	 }
private:
    //! Copy constructor - No copy allowed
	Visdef(const Visdef&);
    //! Overloaded << operator to copy - No copy allowed
	Visdef& operator=(const Visdef&);
    
// -- Friends
    //! Overloaded << operator to call print().
	friend ostream& operator<<(ostream& s,const Visdef<P>& p)
		{ p.print(s); return s; }

};

} // namespace magics

#endif

==> magics++_2.18.15.orig.tar.gz: magics++-2.18.15/src/basic/Visdef.h <==
/******************************** LICENSE ********************************

 Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at 

    http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 ******************************** LICENSE ********************************/

/*! \file Visdef.h
    \brief Definition of the Template class Visdef.
    
    Magics Team - ECMWF 2007
    
    Started: Fri 16-Mar-2007
    
    Changes:
    
*/

#ifndef Visdef_H
#define Visdef_H

#include "magics.h"
#include "BasicSceneObject.h"
#include "Data.h"


namespace magics {

class MetaDataVisitor;
class Transformation;
class HistoVisitor;
class Colour;
template <class T > class IntervalMap;


class Visdef : public MetviewIcon  {

public:
	Visdef() {}
	virtual ~Visdef() {}
	

	virtual void operator()(Data&, BasicGraphicsObjectContainer&) = 0;
	virtual void visit(LegendVisitor&) {}
	virtual void visit(Data&, LegendVisitor& legend) { this->visit(legend);}
	virtual void visit(Data&, HistoVisitor&)
	{ 
		MagLog::dev() << "Here could build a basic histogram!" << endl; 
	}
    virtual void visit(MetaDataVisitor&) {}
    virtual void visit(TopAxisVisitor&) {}
    virtual void visit(Transformation&, Data&) {}
    virtual void visit(Layer& layer) { MetviewIcon::visit(layer); }
    virtual void beanInfo(IntervalMap<Colour>&) { assert(false); }
    virtual bool needLegend() { return false; }
protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
	 virtual void print(ostream& out) const { 
	 	out << "visdef"; 
	 }
	 
private:
    //! Copy constructor - No copy allowed
	Visdef(const Visdef&);
    //! Overloaded << operator to copy - No copy allowed
	Visdef& operator=(const Visdef&);
    
// -- Friends
    //! Overloaded << operator to call print().
	friend ostream& operator<<(ostream& s,const Visdef& p)
		{ p.print(s); return s; }

};

} // namespace magics

#endif
